@@ -8,7 +8,7 @@ use Data::Dumper;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 our $AUTOLOAD;
 
 sub new {
@@ -21,6 +21,7 @@ sub new {
     $self->{_voice}              = $args->{voice}   ||= undef;
     $self->{_languages}          = [];
     $self->{_pronounce}          = [];
+    $self->{_SWAIG}->{include}   = [];
     $self->{_SWAIG}->{functions} = [];
     $self->{_SWAIG}->{defaults}  = {};
     return bless($self, $class);
@@ -179,6 +180,17 @@ sub add_ailanguage {
     return;
 }
 
+# Function included in SWAIG
+sub add_aiinclude {
+	my $self    = shift;
+	my $include = shift;
+
+	@{ $self->{_SWAIG}->{include} } = (@{ $self->{_SWAIG}->{include}}, $include);
+
+	return;
+}
+
+
 #set post_prompt
 sub set_aipost_prompt {
     my $self       = shift;
